@@ -12,7 +12,7 @@ class TestExposeProcess(utils.TestCaseWithLoop):
     def setUp(self):
         super(TestExposeProcess, self).setUp()
 
-        def validator_function(input):
+        def validator_function(input, port):
             pass
 
         class BaseNamespaceProcess(NewLoopProcess):
@@ -72,12 +72,7 @@ class TestExposeProcess(utils.TestCaseWithLoop):
         port_namespace_left.__dict__.pop('_ports', None)
         port_namespace_right.__dict__.pop('_ports', None)
 
-        # The `_value_spec` is a nested dictionary so should be compared explicitly separately
-        value_spec_left = port_namespace_left._value_spec
-        value_spec_right = port_namespace_right._value_spec
-
         self.assertEqual(port_namespace_left.__dict__, port_namespace_right.__dict__)
-        self.assertEqual(value_spec_left.__dict__, value_spec_right.__dict__)
 
     def test_expose_nested_namespace(self):
         """Test that expose_inputs can create nested namespaces while maintaining own ports."""
@@ -188,7 +183,7 @@ class TestExposeProcess(utils.TestCaseWithLoop):
         properties with that of the exposed process
         """
 
-        def validator_function(input):
+        def validator_function(input, port):
             pass
 
         # Define child process with all mutable properties of the inputs PortNamespace to a non-default value
@@ -235,7 +230,7 @@ class TestExposeProcess(utils.TestCaseWithLoop):
         namespace_options will be the end-all-be-all
         """
 
-        def validator_function(input):
+        def validator_function(input, port):
             pass
 
         # Define child process with all mutable properties of the inputs PortNamespace to a non-default value
@@ -288,7 +283,7 @@ class TestExposeProcess(utils.TestCaseWithLoop):
         namespace with the properties of the exposed port namespace
         """
 
-        def validator_function(input):
+        def validator_function(input, port):
             pass
 
         # Define child process with all mutable properties of the inputs PortNamespace to a non-default value
