@@ -25,26 +25,14 @@ class TestWaitingProcess(utils.TestCaseWithLoop):
 
             self.assertTrue(check_process_against_snapshots(self.loop, proc_class, saver.snapshots))
 
-    def test_abort(self):
+    def test_kill(self):
         process = WaitForSignalProcess()
-        process.add_on_waiting_callback(lambda _: process.pause())
-        process.execute()
-        process.kill()
+
+        # Kill the process when it enters the WAITING state
+        listener = plumpy.ProcessListener()
+        listener.on_process_waiting = lambda _proc: process.kill()
+        process.add_process_listener(listener)
+
+        with self.assertRaises(plumpy.KilledError):
+            process.execute()
         self.assertTrue(process.killed())
-
-    def _check_process_against_snapshot(self, snapshot, proc):
-        self.assertEqual(snapshot.state, proc.state)
-
-        new_bundle = plumpy.Bundle()
-        proc.save_instance_state(new_bundle)
-        self.assertEqual(snapshot.bundle, new_bundle,
-                         "Bundle mismatch with process class {}\n"
-                         "Snapshot:\n{}\n"
-                         "Loaded:\n{}".format(
-                             proc.__class__, snapshot.bundle, new_bundle))
-
-        self.assertEqual(snapshot.outputs, proc.outputs,
-                         "Outputs mismatch with process class {}\n"
-                         "Snapshot:\n{}\n"
-                         "Loaded:\n{}".format(
-                             proc.__class__, snapshot.outputs, proc.outputs))
